@@ -1,5 +1,4 @@
-'''Statistical Data and Metadata eXchange (SDMX) for the Python data ecosystem'''
-
+"""Statistical Data and Metadata eXchange (SDMX) for the Python data ecosystem"""
 
 
 from pandasdmx.api import Request, read_url
@@ -21,7 +20,7 @@ __all__ = [
     "to_xml",
 ]
 
-__version__ = "1.2.0"
+__version__ = "1.3.0"
 
 
 #: Top-level logger.
